@@ -22,6 +22,7 @@
 #include "storage.h"
 #include "learner.h"
 
+#include <memory>
 #include <QObject>
 #include <QList>
 #include "liblearner_debug.h"
@@ -45,7 +46,7 @@ public:
     QList<Learner*> m_profiles;
     Learner *m_activeProfile;
     QList<LearningGoal*> m_goals;
-    KConfig *m_config;
+    std::unique_ptr<KConfig> m_config;
     Storage m_storage;
 };
 }
@@ -53,15 +54,14 @@ public:
 LearnerProfile::ProfileManagerPrivate::ProfileManagerPrivate()
     : m_profiles(QList<Learner*>())
     , m_activeProfile(nullptr)
-    , m_config(nullptr)
+    , m_config(new KConfig(QStringLiteral("learnerprofilerc")))
 {
     // load all profiles from storage
     m_goals.append(m_storage.loadGoals());
     m_profiles.append(m_storage.loadProfiles(m_goals));
 
     // set last used profile
-    m_config = new KConfig(QStringLiteral("learnerprofilerc"));
-    KConfigGroup activeProfileGroup(m_config, "ActiveProfile");
+    KConfigGroup activeProfileGroup(m_config.get(), "ActiveProfile");
     int lastProfileId = activeProfileGroup.readEntry("profileId", "0").toInt();
     QList<int> activeGoalsCategories = activeProfileGroup.readEntry("activeGoalsCategories", QList<int>());
     QList<QString> activeGoalsIdentifiers = activeProfileGroup.readEntry("activeGoalsIdentifiers", QList<QString>());
@@ -72,17 +72,17 @@ LearnerProfile::ProfileManagerPrivate::ProfileManagerPrivate()
             if (activeGoalsCategories.count() == activeGoalsIdentifiers.count()) {
                 for (int i = 0; i < activeGoalsCategories.count(); ++i) {
                     m_activeProfile->setActiveGoal(
-                        (Learner::Category) activeGoalsCategories.at(i),
+                        static_cast<Learner::Category>(activeGoalsCategories.at(i)),
                         activeGoalsIdentifiers.at(i));
                 }
             } else {
-                qCritical() << "Inconsistent goal category / identifier pairs found: aborting.";
+                qCCritical(LIBLEARNER_LOG()) << "Inconsistent goal category / identifier pairs found: aborting.";
             }
             break;
         }
     }
     if (m_activeProfile == nullptr) {
-        qCDebug(LIBLEARNER_LOG) << "No last active profile found, falling back to first found profile";
+        qCDebug(LIBLEARNER_LOG()) << "No last active profile found, falling back to first found profile";
         if (m_profiles.size() > 0) {
             m_activeProfile = m_profiles.at(0);
         }
@@ -93,7 +93,7 @@ void ProfileManagerPrivate::sync()
 {
     // sync last used profile data
     if (m_activeProfile) {
-        KConfigGroup activeProfileGroup(m_config, "ActiveProfile");
+        KConfigGroup activeProfileGroup(m_config.get(), "ActiveProfile");
         activeProfileGroup.writeEntry("profileId", m_activeProfile->identifier());
 
         // compute activer learning goals by category
@@ -101,19 +101,19 @@ void ProfileManagerPrivate::sync()
         QList<QString> goalIdentifiers;
         // compute used goals
         foreach (LearningGoal *goal, m_activeProfile->goals()) {
-            if (!goalCatogries.contains((int) goal->category())) {
-                goalCatogries.append((int) goal->category());
+            if (!goalCatogries.contains(static_cast<int>(goal->category()))) {
+                goalCatogries.append(static_cast<int>(goal->category()));
             }
         }
         // compute active goals
         foreach (int category, goalCatogries) {
-            goalIdentifiers.append(m_activeProfile->activeGoal((Learner::Category) category)->identifier());
+            goalIdentifiers.append(m_activeProfile->activeGoal(static_cast<Learner::Category>(category))->identifier());
         }
         activeProfileGroup.writeEntry("activeGoalsCategories", goalCatogries);
         activeProfileGroup.writeEntry("activeGoalsIdentifiers", goalIdentifiers);
     }
     else {
-        qCritical() << "No active profile selected, aborting sync.";
+        qCCritical(LIBLEARNER_LOG()) << "No active profile selected, aborting sync.";
     }
     m_config->sync();
 
@@ -133,16 +133,18 @@ ProfileManager::ProfileManager(QObject *parent)
     connect (this, &ProfileManager::profileRemoved, this, &ProfileManager::profileCountChanged);
 
     foreach (Learner *learner, d->m_profiles) {
-        connect (learner, SIGNAL(goalRemoved(Learner*,LearningGoal*)),
-                this, SLOT(removeLearningGoal(Learner*,LearningGoal*)));
+        connect(learner, &Learner::goalRemoved, this, &ProfileManager::removeLearningGoal);
     }
 }
 
 ProfileManager::~ProfileManager()
 {
-    foreach (Learner *learner, d->m_profiles) {
+    for (auto learner : d->m_profiles) {
         learner->deleteLater();
     }
+    for (auto goal : d->m_goals) {
+        goal->deleteLater();
+    }
 }
 
 QList< Learner* > ProfileManager::profiles() const
@@ -157,7 +159,8 @@ int ProfileManager::profileCount() const
 
 void ProfileManager::openImageFileDialog()
 {
-    const QString imagePath = QFileDialog::getOpenFileName(0,
+    const QString imagePath = QFileDialog::getOpenFileName(
+        nullptr,
         i18n("Open Image"),
         QLatin1String(""),
         i18n("Image Files (*.png *.jpg *.bmp)"));
@@ -182,7 +185,7 @@ Learner * ProfileManager::addProfile(const QString &name)
     d->m_storage.storeProfile(learner);
     emit profileAdded(learner, d->m_profiles.count() - 1);
 
-    if (activeProfile() == 0) {
+    if (activeProfile() == nullptr) {
         setActiveProfile(learner);
     }
 
@@ -196,7 +199,7 @@ void ProfileManager::removeProfile(Learner *learner)
 {
     int index = d->m_profiles.indexOf(learner);
     if (index < 0) {
-        qCWarning(LIBLEARNER_LOG) << "Profile was not found, aborting";
+        qCWarning(LIBLEARNER_LOG()) << "Profile was not found, aborting";
         return;
     }
     emit profileAboutToBeRemoved(index);
@@ -266,6 +269,10 @@ void ProfileManager::recordProgress(Learner *learner,
                                     const QString &container, const QString &item,
                                     int logPayload, int valuePayload)
 {
+    if (!learner) {
+        qCDebug(LIBLEARNER_LOG()) << "No learner set, no data stored";
+        return;
+    }
     d->m_storage.storeProgressLog(learner, goal, container, item, logPayload, QDateTime::currentDateTime());
     d->m_storage.storeProgressValue(learner, goal, container, item, valuePayload);
 }
