@@ -20,33 +20,38 @@
 
 #include "application.h"
 
-#include "core/skeleton.h"
-#include "core/course.h"
+#include "core/iresourcerepository.h"
+#include "core/ieditablerepository.h"
+#include "core/ilanguage.h"
 #include "core/language.h"
-#include "core/resourcemanager.h"
-#include "core/unit.h"
-#include "core/phrase.h"
+#include "core/contributorrepository.h"
+#include "core/drawertrainingactions.h"
+#include "core/trainingaction.h"
+#include "core/editorsession.h"
 #include "core/phoneme.h"
 #include "core/phonemegroup.h"
-#include "core/trainingsession.h"
-#include "core/editorsession.h"
+#include "core/phrase.h"
 #include "core/player.h"
 #include "core/recorder.h"
-#include "models/coursemodel.h"
+#include "core/trainingsession.h"
+#include "core/unit.h"
+#include "core/resources/editablecourseresource.h"
+#include "core/resources/skeletonresource.h"
 #include "models/coursefiltermodel.h"
+#include "models/coursemodel.h"
 #include "models/languagemodel.h"
 #include "models/languageresourcemodel.h"
 #include "models/learningprogressmodel.h"
-#include "models/unitmodel.h"
-#include "models/unitfiltermodel.h"
-#include "models/phrasemodel.h"
-#include "models/phraselistmodel.h"
-#include "models/phrasefiltermodel.h"
-#include "models/phonememodel.h"
 #include "models/phonemegroupmodel.h"
+#include "models/phonememodel.h"
 #include "models/phonemeunitmodel.h"
+#include "models/phrasefiltermodel.h"
+#include "models/phraselistmodel.h"
+#include "models/phrasemodel.h"
 #include "models/profilemodel.h"
 #include "models/skeletonmodel.h"
+#include "models/unitfiltermodel.h"
+#include "models/unitmodel.h"
 #include "qmlcontrols/iconitem.h"
 
 #include "liblearnerprofile/src/learner.h"
@@ -54,10 +59,10 @@
 #include "liblearnerprofile/src/learninggoal.h"
 #include "liblearnerprofile/src/models/learninggoalmodel.h"
 
+#include <QObject>
 #include <QQmlComponent>
 #include <QQmlContext>
 #include <QQmlEngine>
-#include <QGraphicsDropShadowEffect>
 
 Application::Application(int& argc, char** argv)
     : QApplication(argc, argv)
@@ -65,6 +70,21 @@ Application::Application(int& argc, char** argv)
     registerQmlTypes();
 }
 
+IResourceRepository * Application::resourceRepository() const
+{
+    return m_resourceRepository;
+}
+
+IEditableRepository * Application::editableRepository() const
+{
+    return qobject_cast<IEditableRepository*>(m_resourceRepository);
+}
+
+void Application::installResourceRepository(IResourceRepository *resourceRepository)
+{
+    m_resourceRepository = resourceRepository;
+}
+
 void Application::registerQmlTypes()
 {
     qmlRegisterUncreatableType<TrainingSession>(
@@ -75,29 +95,45 @@ void Application::registerQmlTypes()
         "artikulate", 1, 0,
         "EditorSession",
         QStringLiteral("EditorSession is unique object provided by the backend"));
-    qmlRegisterUncreatableType<ResourceManager>(
+    qmlRegisterUncreatableType<ContributorRepository>(
         "artikulate", 1, 0,
-        "ResourceManager",
-        QStringLiteral("ResourceManager is unique object provided by the backend"));
+        "ContributorRepository",
+        QStringLiteral("ContributorRepository is unique object provided by the backend"));
     qmlRegisterUncreatableType<LearnerProfile::ProfileManager>(
         "artikulate", 1, 0,
         "ProfileManager",
         QStringLiteral("ProfileManager is unique object provided by the backend"));
+    qmlRegisterUncreatableType<EditableCourseResource>(
+        "artikulate", 1, 0,
+        "EditableCourseResource",
+        QStringLiteral("EditableCourseResource objects are backend objects"));
+    qmlRegisterUncreatableType<SkeletonResource>(
+        "artikulate", 1, 0,
+        "SkeletonResource",
+        QStringLiteral("SkeletonResource objects are backend objects"));
 
+    // interfaces
+    qmlRegisterInterface<IResourceRepository>("IResourceRepository");
+    qmlRegisterInterface<IResourceRepository>("IEditableRepository");
+    qmlRegisterInterface<ICourse>("ICourse");
+    qmlRegisterInterface<IEditableCourse>("IEditableCourse");
+    qmlRegisterInterface<ICourse>("ILanguage");
+
+    // concrete instantiable types
     qmlRegisterType<LearnerProfile::Learner>("artikulate", 1, 0, "Learner");
     qmlRegisterType<LearnerProfile::LearningGoal>("artikulate", 1, 0, "LearningGoal");
     qmlRegisterType<Unit>("artikulate", 1, 0, "Unit");
-    qmlRegisterType<Skeleton>("artikulate", 1, 0, "Skeleton");
-    qmlRegisterType<Course>("artikulate", 1, 0, "Course");
     qmlRegisterType<Language>("artikulate", 1, 0, "Language");
-    qmlRegisterType<ResourceManager>("artikulate", 1, 0, "ResourceManager");
     qmlRegisterType<Phrase>("artikulate", 1, 0, "Phrase");
     qmlRegisterType<Phoneme>("artikulate", 1, 0, "Phoneme");
     qmlRegisterType<PhonemeGroup>("artikulate", 1, 0, "PhonemeGroup");
     qmlRegisterType<Player>("artikulate", 1, 0, "Player");
     qmlRegisterType<Recorder>("artikulate", 1, 0, "Recorder");
     qmlRegisterType<IconItem>("artikulate", 1, 0, "Icon");
+    qmlRegisterType<DrawerTrainingActions>("artikulate", 1, 0, "DrawerTrainingActions");
+    qmlRegisterType<TrainingAction>("artikulate", 1, 0, "TrainingAction");
 
+    // models
     qmlRegisterType<CourseModel>("artikulate", 1, 0, "CourseModel");
     qmlRegisterType<CourseFilterModel>("artikulate", 1, 0, "CourseFilterModel");
     qmlRegisterType<LanguageModel>("artikulate", 1, 0, "LanguageModel");
