@@ -22,53 +22,55 @@
 #define LANGUAGE_H
 
 #include "artikulatecore_export.h"
+#include "ilanguage.h"
+#include <memory>
 #include <QObject>
-#include <QList>
+#include <QVector>
 #include <QUrl>
 
 class QString;
 class Phoneme;
 class PhonemeGroup;
 
-class ARTIKULATECORE_EXPORT Language : public QObject
+class ARTIKULATECORE_EXPORT Language : public ILanguage
 {
     Q_OBJECT
+    Q_INTERFACES(ILanguage)
+
     Q_PROPERTY(QString id READ id WRITE setId NOTIFY idChanged)
     Q_PROPERTY(QString title READ title WRITE setTitle NOTIFY titleChanged)
     Q_PROPERTY(QString i18nTitle READ i18nTitle WRITE seti18nTitle NOTIFY i18nTitleChanged)
 
 public:
-    explicit Language(QObject *parent = 0);
-    ~Language();
+    static std::shared_ptr<Language> create(QUrl file);
+    ~Language() override;
 
-    QString id() const;
+    QString id() const override;
     void setId(const QString &id);
-    QString title() const;
+    QString title() const override;
     void seti18nTitle(const QString &title);
-    QString i18nTitle() const;
+    QString i18nTitle() const override;
     void setTitle(const QString &title);
     QUrl file() const;
     void setFile(const QUrl &file);
-    QList<Phoneme *> phonemes() const;
-    Phoneme * addPhoneme(const QString &identifier, const QString &title);
-    QList<PhonemeGroup *> phonemeGroups() const;
-    PhonemeGroup * addPhonemeGroup(const QString &identifier, const QString &title);
+    QVector<std::shared_ptr<Phoneme>> phonemes() const override;
+    QVector<std::shared_ptr<PhonemeGroup>> phonemeGroups() const override;
 
-signals:
+Q_SIGNALS:
     void idChanged();
-    void associatedLanguageItemChanged();
     void titleChanged();
     void i18nTitleChanged();
     void phonemesChanged();
-    void phonemeGroupsChanged();
+
+protected:
+    explicit Language();
 
 private:
-    Q_DISABLE_COPY(Language)
     QString m_id;
     QString m_title;
     QString m_i18nTitle;
     QUrl m_file;
-    QList<PhonemeGroup *> m_phonemeGroups;
+    QVector<std::shared_ptr<PhonemeGroup>> m_phonemeGroups;
 };
 
 #endif // LANGUAGE_H
